@@ -13,7 +13,7 @@ VALID_UTM_PARAMS = [
 
 def parse_qs(request: HttpRequest) -> UtmParamsDict:
     """
-    Extract 'utm_*' values from request querystring.
+    Extract 'utm_*'+ values from request querystring.
 
     NB in the case where there are multiple values for the same key,
     this will extract the last one. Multiple values for utm_ keys
@@ -21,8 +21,14 @@ def parse_qs(request: HttpRequest) -> UtmParamsDict:
     unpredictable outcome. Look after your querystrings.
 
     """
-    return {
+    utm_keys = {
         str(k).lower(): str(v).lower()
         for k, v in request.GET.items()
         if k in VALID_UTM_PARAMS and v != ""
     }
+
+    if gclid := request.GET.get("gclid"):
+        # We don't want to lowercase the gclid
+        utm_keys["gclid"] = gclid
+
+    return utm_keys
